==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AClassNameSingleClassNameList.h <==
// public final class soot.jimple.parser.node.AClassNameSingleClassNameList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f20c43d68f5b6077 soot_jimple_parser_node_AClassNameSingleClassNameList
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class c9c2d090d97715b6 soot_jimple_parser_node_PClassNameList

// header file dependencies
// @dep_header soot_jimple_parser_node_PClassNameList

#include "soot/jimple/parser/node/PClassNameList.h"

#ifndef _JC_soot_jimple_parser_node_AClassNameSingleClassNameList_H_
#define _JC_soot_jimple_parser_node_AClassNameSingleClassNameList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PClassName$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$sub_refs	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$sub_nonrefs	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$refs	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$refs;
typedef struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$nonrefs	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object;

typedef const struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vmethods	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vtable	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vtable;
typedef const struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vtype	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *);
extern void _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method$_init$f4d6cb5b3e937cec(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *, struct _jc_soot_jimple_parser_node_PClassName$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *);
extern struct _jc_soot_jimple_parser_node_PClassName$object *_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method$getClassName$a22018ca45a96d40(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *);
extern void _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method$setClassName$594cf5bacd7331dd(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *, struct _jc_soot_jimple_parser_node_PClassName$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method_info$getClassName$a22018ca45a96d40;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method_info$setClassName$594cf5bacd7331dd;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *);
	struct _jc_soot_jimple_parser_node_PClassName$object	*(*getClassName$a22018ca45a96d40)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setClassName$594cf5bacd7331dd)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *, struct _jc_soot_jimple_parser_node_PClassName$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PClassNameList$vmethods	soot_jimple_parser_node_PClassNameList;
	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vmethods	soot_jimple_parser_node_AClassNameSingleClassNameList;
};

// Vtype
struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$sub_refs {
	struct _jc_soot_jimple_parser_node_PClassName$object	*__5fclassName__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$refs {
    _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$sub_refs	soot_jimple_parser_node_AClassNameSingleClassNameList;
    _jc_soot_jimple_parser_node_PClassNameList$sub_refs	soot_jimple_parser_node_PClassNameList;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PClassNameList$sub_nonrefs	soot_jimple_parser_node_PClassNameList;
    _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$sub_nonrefs	soot_jimple_parser_node_AClassNameSingleClassNameList;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object {
	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vtype	*vtype;
	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vtype _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AClassNameSingleClassNameList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$class_object;

#endif	/* _JC_soot_jimple_parser_node_AClassNameSingleClassNameList_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AClassNameSingleClassNameList.h <==
// public final class soot.jimple.parser.node.AClassNameSingleClassNameList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f20c43d68f5b6077 soot_jimple_parser_node_AClassNameSingleClassNameList
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class c9c2d090d97715b6 soot_jimple_parser_node_PClassNameList

// header file dependencies
// @dep_header soot_jimple_parser_node_PClassNameList

#include "soot/jimple/parser/node/PClassNameList.h"

#ifndef _JC_soot_jimple_parser_node_AClassNameSingleClassNameList_H_
#define _JC_soot_jimple_parser_node_AClassNameSingleClassNameList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PClassName$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$sub_refs	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$sub_nonrefs	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$refs	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$refs;
typedef struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$nonrefs	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object;

typedef const struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vmethods	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vtable	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vtable;
typedef const struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vtype	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method$_init$f4d6cb5b3e937cec(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *, struct _jc_soot_jimple_parser_node_PClassName$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PClassName$object *_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method$getClassName$a22018ca45a96d40(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method$setClassName$594cf5bacd7331dd(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *, struct _jc_soot_jimple_parser_node_PClassName$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method_info$getClassName$a22018ca45a96d40;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method_info$setClassName$594cf5bacd7331dd;
extern _jc_method _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PClassName$object	*(*getClassName$a22018ca45a96d40)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setClassName$594cf5bacd7331dd)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *, struct _jc_soot_jimple_parser_node_PClassName$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PClassNameList$vmethods	soot_jimple_parser_node_PClassNameList;
	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vmethods	soot_jimple_parser_node_AClassNameSingleClassNameList;
};

// Vtype
struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$sub_refs {
	struct _jc_soot_jimple_parser_node_PClassName$object	*__5fclassName__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$refs {
    _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$sub_refs	soot_jimple_parser_node_AClassNameSingleClassNameList;
    _jc_soot_jimple_parser_node_PClassNameList$sub_refs	soot_jimple_parser_node_PClassNameList;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PClassNameList$sub_nonrefs	soot_jimple_parser_node_PClassNameList;
    _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$sub_nonrefs	soot_jimple_parser_node_AClassNameSingleClassNameList;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$object {
	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vtype	*vtype;
	_jc_soot_jimple_parser_node_AClassNameSingleClassNameList$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$vtype _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AClassNameSingleClassNameList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AClassNameSingleClassNameList$class_object;

#endif	/* _JC_soot_jimple_parser_node_AClassNameSingleClassNameList_H_ */
